#
# spec file for package tini
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tini
Version:        0.19.0
Release:        2.5
Summary:        A tiny but valid init for containers
License:        MIT
Group:          System/Management
URL:            https://github.com/krallin/tini
Source:         %{URL}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  glibc-devel-static

%description
Tini is a trivial implementation for an "init" program.

All Tini does is spawn a single child (Tini is meant to be run in a container),
and wait for it to exit, all the while reaping zombies and performing signal forwarding.

libc will be needed inside the container.

%package static
Summary:        A tiny but valid init for containers, with libc linked statically
Group:          System/Management

%description static
Tini is a trivial implementation for an "init" program.

All Tini does is spawn a single child (Tini is meant to be run in a container),
and wait for it to exit, all the while reaping zombies and performing signal forwarding.

This variant is statically linked to libc so that it will not be
needed inside the container.

%prep
%autosetup

%build
# Subreaper requires kernel >= 3.4
%set_build_flags
CFLAGS="${CFLAGS-} -DPR_SET_CHILD_SUBREAPER=36 -DPR_GET_CHILD_SUBREAPER=37"
export CFLAGS

# Enable DMINIMAL to supress verbosity or any output at all, plus disable
# argument parsing. You an still set some options via env vars
# CMAKE_ARGS="-DMINIMAL=ON"
%cmake .
%make_build tini
%make_build tini-static

%install
mkdir -p %{buildroot}/%{_sbindir}
cp build/tini %{buildroot}/%{_sbindir}/tini
cp build/tini-static %{buildroot}/%{_sbindir}/tini-static

%files
%license LICENSE
%doc README.md
%{_sbindir}/tini

%files static
%{_sbindir}/tini-static
%license LICENSE
%doc README.md

%changelog
* Thu May  4 2023 Dan Čermák <dcermak@suse.com>
- Modernize spec: use %%cmake & %%set_build_flags macros
- Install tini into %%_sbindir to adhere to FHS
- Install docs & license for static subpackage as well
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.19.0:
  * mipsel build (#147)
  * include checksums in releases
  * ppc64le alias for the ppc64el build
* Sun May  5 2019 Stephan Kulow <coolo@suse.com>
- Update to 0.18.0
  - Added -w to warn when orphaned processes are reaped (#107)
  - Added -e to expect non-zero exit codes (and rewrite them as zeroe) (#75)
  - Configure pdeathsignal (#114)
  - Environment variable for -g (#101)
* Sun Nov 11 2018 Jan Engelhardt <jengelh@inai.de>
- Remove empty scriptlets. Trim bias from descriptions.
* Fri Apr  6 2018 blaine.gardner@suse.com
- Fix spec file bug where both the static and non-static RPMs installed the non-static binary only.
- The "tini" binary now installs to "/tini" and "tini-static" now installs to "/tini-static"
  to reflect the installation suggested on the tini GitHub page.
* Tue Feb  6 2018 blaine.gardner@suse.com
- Update Tini version to 0.16.1
- Major Tini changes:
  + Fixed a bug that prevented subreaper mode from working in
    dynamically-linked Tinis on recent distributions (Tini issue #67)
* Thu Apr 13 2017 jmassaguerpla@suse.com
- initial commit
